#
# spec file for package drbd (Version 8.3.8.1)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           drbd
BuildRequires:  bison flex udev
Summary:        Distributed Replicated Block Device
Version:        8.3.9
Release:        7.1
Source:         %{name}-%{version}.tar.bz2
Patch1:         init-script-fixes.diff
License:        GPLv2+
Group:          Productivity/Clustering/HA
Provides:       drbdsetup drbd-control
Url:            http://www.drbd.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): %insserv_prereq %fillup_prereq
Requires(preun): %insserv_prereq %fillup_prereq
Requires(postun): %insserv_prereq fileutils

%description
Drbd is a distributed replicated block device. It mirrors a block
device over the network to another machine. Think of it as networked
raid 1. It is a building block for setting up clusters.



Authors:
--------
    Philipp Reisner <philipp.reisner@linbit.com>
    Lars Ellenberg <lars.ellenberg@linbit.com>

%prep
%setup
%patch1

%build
PATH=/sbin:$PATH %configure \
    --without-km \
    --with-utils \
    --with-udev \
    --with-distro=suse \
    --with-heartbeat \
    --with-pacemaker \
    --with-xen \
    --with-bashcompletion

make OPTFLAGS="$RPM_OPT_FLAGS" %{?_smp_mflags}

%install
%makeinstall
ln -sf ../etc/init.d/drbd $RPM_BUILD_ROOT/sbin/rcdrbd
mkdir -p $RPM_BUILD_ROOT/var/lib/drbd
#
# and I only want to install a hint to the example conf
#
cat <<___ > $RPM_BUILD_ROOT/etc/drbd.conf
#
# please have a a look at the example configuration file in
# %{_docdir}/drbd/drbd.conf
#
___
#
%ifnarch %ix86 x86_64
rm -rf $RPM_BUILD_ROOT/etc/xen
%endif

%clean
rm -rf "$RPM_BUILD_ROOT"

%post
%{fillup_and_insserv}

%preun
%{stop_on_removal}

%postun
%{insserv_cleanup}

%files -n drbd
%defattr(-, root, root)
%config(noreplace) /etc/drbd.conf
/etc/bash_completion.d/drbdadm.sh
%config /etc/drbd.d/global_common.conf
%doc %{_mandir}/man5/drbd.conf.5*
%doc %{_mandir}/man8/drbd.8*
%doc %{_mandir}/man8/drbdsetup.8*
%doc %{_mandir}/man8/drbdadm.8*
%doc %{_mandir}/man8/drbddisk.8*
%doc %{_mandir}/man8/drbdmeta.8*
%doc COPYING
%doc README
%doc ChangeLog
%doc scripts/drbd.conf
%dir /etc/drbd.d
/sbin/drbdadm
/sbin/drbdsetup
/sbin/rcdrbd
/sbin/drbdmeta
/usr/sbin/drbd-overview
%ifarch %ix86 x86_64
%dir /etc/xen
%dir /etc/xen/scripts
/etc/xen/scripts/block-drbd
%endif
/usr/lib/ocf/resource.d/linbit/drbd
/etc/ha.d/resource.d/drbddisk
/etc/ha.d/resource.d/drbdupper
%dir /etc/udev
%dir /etc/udev/rules.d
/etc/udev/rules.d/65-drbd.rules
%config /etc/init.d/drbd
%defattr(-, root, root)
/var/lib/drbd
/usr/lib/drbd
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/linbit
%dir /etc/ha.d
%dir /etc/ha.d/resource.d

%changelog
* Tue Mar 20 2012 tserong@suse.com
- update to 8.3.9 (bnc#680338)
  * Fix for possible deadlock on IO error during resync
  * Fixed a race condition between adding and removing network configuration.
  Lead to a BUG_ON() when triggered.
  * Fixed spurious full syncs that could happen after an empty resync and
  concurrent connection loss.
  * Fixed spurious full syncs that happened when connection got lost while
  one node was in WFSyncUUID state (Bugz 318)
  * Fixed a race in the meta-data update code path, that could lead to forgotten
  updates to the meta-data. That in fact could lead to unexpected behavior
  at the next connect
  * Fixed potential deadlock on detach
  * Fixed potential data divergence after multiple failures
  * Implicitly create unconfigured devices which are referenced in sync-after
  dependencies.
  * OCF RA now also works with pacemaker 1.1
  * Allow BIO sizes of up to 128kByte. Note: In case drbd-proxy is used, at least
  version 1.0.16 of drbd-proxy is required.
  * New configuration keyword on-no-data-accessible. Possible values
  io-error, and suspend-io. The default is "io-error", which matches the
  previous behavior.
  * If the fencing policy is set to resource-and-stonith, the primary node
  will creates the new current UUID _after_ the fencing handler
  returned. (Before it did immediately)
  * Rewrote the resync speed control loop code. New configuration parameters
  c-plan-ahead, c-fill-target, c-delay-target, c-max-rate, c-min-rate.
  * Disable activity log updates when all blocks of an unconnected device is
  are out of sync. That can be activated by using "invalidate-remote" on an
  unconnected primary.
  * Improved IPv6 support: link local addresses
  * Improved resync speed display in /proc/drbd
* Thu Oct 21 2010 ro@suse.de
- update to 8.3.8.1
  * Revert delay probes, they could potentially lead to stalled resync.
    Feature is being re-implemented differently
  * DRBD ocf resource agent now treats hostnames case insensitive
- update to 8.3.8
  * Do not expose failed local READs to upper layers, regression introduced
    in 8.3.3
  * Fixed support for devices with 4k hard sector size (again)
  * Fixed a potential Oops in the disconnect code
  * Fixed a race condition that could cause DRBD to consider the peers disk
    as Inconstent after resync instead of UpToDate (Bugz 271)
  * Fixed a reace condition that could cause DRBD to consider the peers disk
    as Outdated instead of Inconsistent during resync (Bugz 277)
  * Disallow to start a resync with invalidate / invalidate-remote when the
    source disk is not UpToDate
  * Forcing primary works now also for Consistent, not only for Outdated and
    Inconsistent (Bugz 266)
  * Improved robustness against corrupt or malicous sector addresses when
    receiving data
  * Added the initial-split-brain, it gets called also if the split-brain gets
    automatically resolved
  * Added the --assume-clean option for the resize command, it causes drbd to
    not resync the new storage after an online grow operation
  * drbdadm: Do not segfault if stacked-on-top-of refers to an undefined res
  * drbdadm: Do not consider configs with invalid after statements as invalid
  * drbdadm: Do not segfault if the peer's proxy section is missing
  * drbdadm: Allow nullglob in include statement
  * drbdadm: Fixed the use of waitpid
  * init script: fix insserv headers (Debian 576901)
  * Gave the receiving code the ability to use multiple BIOs for writing a
    single data packet; now DRBD works with BIOs up to 32kByte also on LVM
    devices; from now on the use_bmbv config option does nothing
  * New command check-resize, that allows DRBD to detect offline resizing
    and to move internal meta-data accordingly
  * Added a control loop, that allows DRBD to find auto tune the resync
    speed, on connections with large queues (drbd-proxy)
  * --dry-run option for connect; disconnects after sync handshake
  * --overwrite-data-of-peer got an alias named --force
  * Improvements to crm-fence-peer
  * Fixed option parsing and stacking in snapshot-resync-target-lvm.sh
  * Compiles on 2.6.33 and 2.6.34
- removed patches:
  64bit-fixes.diff (upstream/obsolete)
* Fri Jun 25 2010 tserong@novell.com
- Include Linbit RA
* Sun Apr 11 2010 dmueller@suse.de
- remove KMP subpackage, the kernel modules are part of the kernel
  and don't build out of tree anymore
- update to 8.3.7:
  * Lots of fixes to the new RPM packaging
  * Lots of fixes to the autoconfig stuff
  * Following the rename of CONFIG_LBD to CONFIG_LBDAF
  * Silenced an assert. Could trigger after changing write ordering (Bugz 261)
  * Fixed a race condition between detach and ongoing IO. Very hard to
  trigger, caused an OOPS in make_request/drbd_make_request. (Bugz 262)
  * Fixed a regression in the resync handshake code introduced before 8.3.3.
  That bug causes DRBD to block during the initial handshake when a partial
  resync is not possible but a full resync is necessary. Happens very rarely.
  (Bugz 260)
  * Do not drop into StandAlone mode when connection is lost during authentication
  * Corrected a null test in the authentication code, found by conccinelle,
  thanks to upstream integration. The chance to trigger that was probably 10^-9.
  * crm-fence-peer.sh is now also usable if DRBD is managed from the xen block
  helper script
  * Fixes to the init script's dependencies
  * Backported cleanups that where contributed to the in kernel DRBD
  * Allow online resizing of disconnected devices, new option to drbdsetup
  drbdsetup /dev/drbdX resize --assume-peer-has-space
  * Allow multiple after options in the syncer section for stacked setups
  * Correctly process relative paths in include statements in drbd.conf
  * New option (-t) for drbdadm to test syntax of config snippets
  * Following Linux upstream changes 2.6.32 (SHASH and in_flight issues)
  * New /etc/drbd.conf example that suggests the use of /etc/drbd.d/xxx.res
  * Fixed a regression introduced shortly before 8.3.3, which might
  case a deadlock in DRBD's disconnect code path. (Bugz 258)
  * Fixed drbdsetup X resume-io which is needed for the recovery
  from the effects of broken fence-peer scripts. (Bugz 256)
  * Do not reduce master score of a current Primary on connection loss,
  to avoid unnecessary migrations
  * Do not display the usage count dialog for /etc/inti.d/drbd status
* Fri Jan  8 2010 vuntz@opensuse.org
- Remove unneeded glib-devel BuildRequires.
* Wed Oct  7 2009 aj@suse.de
- update to 8.3.4:
  * Support kernel 2.6.31
  * Numerous bug fixes
  * Support for Infiniband via SDP (sockets direct protocol)
- Add build fix from upstream.
* Sun Jul 19 2009 coolo@novell.com
- trying to get installation right
* Tue Jul 14 2009 teelynn19@aim.com
- update to 8.3.2
  * For kernel 2.6.30 support - see internal changelog of source
* Sun Apr 19 2009 ro@suse.de
- update to 8.3.1
  * Fixed drbdadm invalidate on disconnected devices (reg in 8.2.7)
  * Fixed a hard to trigger spinlock deadlock when using device stacking
    with the upper device having a smaller minor number than the lower device.
    (Bugz 210)
  * Adding a missing range check in ensure_mdev()
  * Implemented a congested_fn; the kernel can keep its pdflushes running now
  * Improvements the connection code for high latency links
  * Fix for several potential memory leaks when allocating a device
  * Use an additional meta data bit to store the fact of an old crashed primary
  * Udev rule that populates /dev/drbd/by-res/ and /dev/drbd/by-disk/
  * New timeout option: outdated-wfc-timeout
  * New drbdmeta option: --ignore-sanity-checks
  * Include statement for drbd.conf
  * Improvements to drbd-overview.pl
  * Fixed snapshot-resync-target-lvm.sh to work with more than 10 devices
  * Do not force a full resync after a detach on a primary node
  * Compatibility with Linux 2.6.27, 2.6.28 and 2.6.29
- update to 8.3.0
  * Fixed 'sleep with spinlock held' in case online verify found a difference
  * Fixed error code pathes in request processing.
  * Fix for stack smashing in drbdmeta
  * Fixed a bug that could lead to a crash when detaching/attaching
    on the primary under heavy IO (Bugz 171)
  * Fixed a bug in the new epoch code (introduced with 8.2.7).
    Might cause crash at reconnect after connection loss during heavy IO
    (Bugz 160)
  * Fixed a bug in drbdsetup that could cause drbdsetup wait-connect to
    miss the connection event.
  * Fixed a race condition in the new barrier code. (Reordered barrier ACKs)
  * Do not rely on blkdev_issue_flush() returning ENOTSUPP
  * bitmap in unmapped pages = support for devices > 4TByte (was DRBD+)
  * checksum based resync (was DRBD+)
  * support for stacked resource (was DRBD+)
  * Added support for stacked resources to the bash completion stuff
  * Added missing documentation (manpages)
  * Fixed drbdadm handlers for stacked resources
  * Support of drbd-proxy in stacked setups
  * RedHat cluster suite (rgmanager) integration scripts
  * Renamed 'state' to 'role'
  * More build compatibility with older vendor kernels
  * Added drbd-overview.pl to the packages
- update filelist
* Tue Jan 13 2009 dgollub@suse.de
- Add kernel-syms-rt to build requires to build SLERT KMPs
* Wed Dec 10 2008 lmb@suse.de
- Update with changes from 8a9ba53abe973301639beacc55eec569b43507e5:
- Fix buffer overflow and off-by-one errors in drbd user-space token
  parser (bnc#450883).
- Fix resizing of devices.
- Fix a NULL pointer dereference in barrier handling.
- Handle failing request better.
- Race in UUID synchronization.
- Fix a call to a blocking function from within a spinlock.
- drbd-optflags.patch: removed, is now upstream.
* Fri Nov 21 2008 lmb@suse.de
- Update from 8.2.7-rc1 to 8.2.7 proper.
- Endianness fixes.
- Handle out-of-sequence barrier acks.
- Allow DRBD to user other cn_idx values in case our default value is
  already taken.
- Although Primary/Diskless/StandAlone is invalid it is not unconfigured
- become UpToDate on both after detach-attach on a connected secondary
  device pair
- 2.6.28 compatibility (needed for SLE11 kernel)
- Bugfixes to write barrier handling.
* Mon Oct 27 2008 lmb@suse.de
- Include fixes from upstream
  (0e87a13b63e2ef87af6cfcc0d875721c53f37ed9).
- Fixed possible Oops on connection loss during sync handshake.
- Latency improvements.
- Improved barrier support.
* Thu Sep  4 2008 lmb@suse.de
- Imported some changes from upstream, including:
- Made it to compile on Linux-2.6.26
- Fixed online resizing if there is application IO on the fly when the
  resize is triggered.
- Fixed online resizing if it is triggered from the secondary node.
- Fixed a possible deadlock in case "become-primary-on-both" is used, and
  a resync starts
- Fixed the invocation of the pri-on-incon-degr handler
- Fixed the exit codes of drbdsetup
- sock_create_lite() to avoid a socket->sk leak
- Auto-tune socket buffers if sndbuf-size is set to zero
* Mon Aug 18 2008 mrueckert@suse.de
- remove outdated options in the fillup_and_insserv call
* Mon Aug 18 2008 schwab@suse.de
- Fix name of completions file.
* Tue Jul 15 2008 lmb@suse.de
- Update to 8.2.6 and include all bugfixes from upstream.
- Fix loading of module (bnc#403731).
- Include bash completion for drbdadm.
- Added the before-resync-target handler.
- Fixed the out-of-sync handler.
- Added the max-bio-bvecs option to workaround issues in a stack of
  DRBD/LVM/Xen.
- Fix online resizing in case if triggered from secondary.
- Includes bugfixes from 8.0.11 -> 8.0.12 branch.
* Wed Jun  4 2008 ro@suse.de
- buildreq xen-tools only on x86,x86_64
* Tue Jun  3 2008 coolo@suse.de
- avoid packaging a directory of xen-tools with different permissions
* Tue Apr 15 2008 lmb@suse.de
- Update to 8.2.5 (FATE#302403)
- Include online-verify + various fixes to it.
- Fix races between online-verify and application writes.
- Fixed data-integrity-alg features.
- Improved latency.
- Full support for migration of meta-data from 0.7 -> 0.8.
- Fix some more races, bugs, and memory leaks.
* Wed Dec  5 2007 ro@suse.de
- hack to compile with 2.6.24
* Tue Sep 18 2007 ro@suse.de
- do really build a module
* Mon Sep 17 2007 lmb@suse.de
- Update to drbd 8.0.6 for kernel-compatibility (310187)
* Wed Apr  4 2007 lrupp@suse.de
- added module-init-tools to BuildRequires
* Fri Mar 30 2007 rguenther@suse.de
- add flex BuildRequires
- add /etc/modprobe.d directory
* Fri Mar 30 2007 ro@suse.de
- added bison to buildreq
* Mon Jan 15 2007 lmb@suse.de
- Update to 0.7.23 for Linux kernels >2.6.19.
* Mon Oct 30 2006 lmb@suse.de
- Update to the officially released 0.7.22 version.
- Implement "freeze_io" feature.
- convert-MODULE_PARM.diff: drop unneeded patch.
* Fri Oct  6 2006 lmb@suse.de
- Update to 0.7.22:
  - In protocol A and B, on connection loss, drbd could "forget" to set
    certain areas out of sync.
  - fix races between failure in drbd_send_dblock and concurrently
    running tl_clear.
  - fix potential access-afer-free in drbd_dio_end.
  - fix possible list corruption respective resulting deadlock in
    receive_DataRequest.
  - improved the drbd_thread_stop / start code.
* Mon Aug 14 2006 lmb@suse.de
- Update to 0.7.21.
  * Fixed the "syncer stalled" after reconnect symptom.
  * Fixed the "stalled in WFParams" after reconnect symptom. The cause
    of this bug was actually a misuse of the data socket.
  * Allow to set the uplug_watermark to 1, only usefull for very strange
    cases.
  * The GC comparison code failed to start a resync in case the two
    cluster node failed simultaniously (common power failure).
  * Fixed DRBD's code to start kernel threads to work on 2.6.17 also.
  * IOCTL return codes fixed for 32bit userland - 64 bit kernel
    setups.
  * New config option "unplug-watermark".
  * Released the drbd_alloc_ee() / drbd_free_ee() implementation from
    the DRBD+ branch to the main branch.
  * Fixed a bug where lc_del() left a list poison in an LRU chache's
    hash table. The only way to trigger this bug was:
    up (>>200M), primary, mkfs, resize to 200M, down, up
  * DRBD now propagates the backing storage's read ahead properties
    to upper layers. With devices that read very fast, this is
    important.
  * GFP_KERNEL was changed to GFP_NOIO in a few places, to make it
    more save against deadlocks in the memory subsystem.
* Thu May  4 2006 lmb@suse.de
- Import fixes from 0.7.18:
- Under high memory pressure it was possible to hit a deadlock on a
  kmalloc(). Changed the GFP mask, it is no longer possible to deadlock
  it with memory pressure.
- With very unlucky network timing during connect DRBD falls into a
  connect / drop-connection loop, that as soon as DRBD is in this loop
  is very stable. This is fixed now, DRBD detects this situation an
  breaks out of it.
- Fix to the init-script. Now it waits until udev has created the device
  nodes of _all_ resources.
- A small fix for the 32bit userland 64bit kernel people, running older
  kernels.
- Improved handling of IO errors during initial read in of the activity
  log.
* Sun Apr  2 2006 agruen@suse.de
- convert-MODULE_PARM.diff: Convert from the obsolete MODULE_PARM
  to the new module_param.
* Mon Mar 27 2006 lmb@suse.de
- Fix memory allocation flags for the activity log (GFP_KERNEL ->
  GFP_NOIO) to avoid possible deadlock.
* Mon Mar  6 2006 lmb@suse.de
- Import upstream fixes from 0.7.17:
  - There was a bug that could cause the activity log to be not applied
  after a primary crash, when an other size than 127 elements was
  configured.
  - There was a bug in the activity log code, that could cause that the
  latest update to the AL is omitted at recovery time.
  - The "Marked additional XXKB as out-of-synced based on AL." message
  showed one one eighth of the real amount.
* Thu Feb 16 2006 lmb@suse.de
- Update to 0.7.16, new fixes:
  - DRBD no longer shrinks an consistent device if it gets connected to
  an smaller peer or attached to a smaller disk.
  - There was a bug related to the degr-wcf-timeout config option, it was
  never used in recent DRBD releases. Fixed.
* Fri Feb  3 2006 agruen@suse.de
- drbd.spec: Replace %%arch with %%_target_cpu.
* Thu Feb  2 2006 ro@suse.de
- added KMP subpackage (required with suse_kernel_module_package)
* Tue Jan 31 2006 lmb@suse.de
- Change km_drbd to a KMP.
- Import fix to deal with serialized recursive calls to
  generic_make_request() and avoid a deadlock (SVN r2056).
* Thu Jan 26 2006 lmb@suse.de
- Compile fix for 2.6.16-rc1.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 lmb@suse.de
- Import some updated documentation.
* Tue Dec 20 2005 lmb@suse.de
- Update to 0.7.15.
* Thu Dec  1 2005 lmb@suse.de
- Update to 0.7.14/SVN.
* Thu Sep  1 2005 lmb@suse.de
- Switch to stable version 0.7.13.
* Thu Jun 30 2005 meissner@suse.de
- use RPM_OPT_FLAGS correctly.
* Mon Feb 21 2005 lmb@suse.de
- Update to upstream 0.8_pre1 (SVN 1763).
* Wed Feb  2 2005 lmb@suse.de
- Update to upstream 0.7.10 (1754).
* Fri Jan 14 2005 ro@suse.de
- fix typo in specfile
* Wed Dec  1 2004 lmb@suse.de
- Update to upstream version 0.7.6.
* Mon Sep 20 2004 lmb@suse.de
- Merge fixes from SLES9 SP1 with STABLE.
* Fri Sep  3 2004 lmb@suse.de
- Realign with upstream.
* Fri Aug 27 2004 lmb@suse.de
- Allow invalidate if cstate<Connected and Secondary
- Data integrity protection: Disallow the user to make a primary node
  SyncTarget via IOCTLs
- Fix modprobe.d documentation (for users who do want to use the new
  block major explicitly).
- Cosmetic: Disable XFS statistics by default.
* Wed Aug 25 2004 lmb@suse.de
- Fix human-count handling to avoid more data inconsistency.
- SLES9/SL9.1: Do NOT use new major number by default.
- Pre-generate documentation. Shorten dependencies even more!
* Mon Aug 16 2004 lmb@suse.de
- Shrink dependency list even further.
* Mon Aug 16 2004 lmb@suse.de
- Remove subversion requirement for building with perl hack.
* Tue Aug 10 2004 lmb@suse.de
- Add modprobe.d file so that upgrading from previous versions is
  smooth.
* Fri Aug  6 2004 lmb@suse.de
- Update to 0.7.2-final (still from SVN).
  - Proper handling of backing storage devices that occasionally fail
    READA (=read ahead) requests. (E.g. LVM and MD) DRBD now fails READA
    requests itself, if a resynchronisation is running and it would need
    to fetch the block from its peer.
  - "drbdadm adjust" had a race, which caused random errors. ( Missing
    waitpid() ). Fixed now.
  - Properly substract SyncPause times from the syncer performance
    numbers.
  - Fix to the syncer progress bar in /proc/drbd.
* Fri Aug  6 2004 lmb@suse.de
- Fix minor module build issue.
* Wed Aug  4 2004 lmb@suse.de
- Upgrade to 0.7.2-pre from SVN
- Changes block major from 43 to officially reserved 147 and from
  /dev/nbXX to /dev/drbdXX.
- Work-around for XFS bug.
- Handle human and timeout counters correctly.
- Some bugfixes and speedups in particular for protocol A and B.
* Wed Jul  7 2004 lmb@suse.de
- Fix various 64bit issues. (Final part of #41538)
* Thu Jul  1 2004 lmb@suse.de
- Reenable fixed zero-copy again. (#42222)
- Fix drbd to work with hard sector sizes != 512bytes (dasd)
  (#41538)
- Fix 64bit problem when calling wait_event_interruptible_timeout()
- Merge upstream code cleanups.
* Fri Jun 18 2004 lmb@suse.de
- Update to drbd-0.7-pre8 from upstream:
  - Disabling zero-copy IO for now (#41852).
  - Bitmap code restructured and lots of bugs fixed.
  - Safe default: Always force a full-resync on initial setup.
  - Ensuring that we never sync/read from an inconsistent peer.
  - Various other fixes.
* Tue Jun  8 2004 lmb@suse.de
- fix ioctls on s390x
- Fix failure in local disk handling.
* Wed Jun  2 2004 lmb@suse.de
- Do not go into in an infinite loop on recursive symlinks under /dev.
- More consistent error handling in the kernel module.
* Tue Jun  1 2004 lmb@suse.de
- Import test harness.
- More fixes from upstream:
  + Rate-limit printks to prevent DoS
  + Test for whether the lower level device is detached in all cases
  + Do not send several Write Hints in a row
* Thu May 27 2004 lmb@suse.de
- Import bugfixes from upstream (equivalent to drbd-0.7-rc1).
  (Replaces some previously separate patches.)
- Fix drbddisk to reply to heartbeat status inquiries correctly.
- Clean up build.
- Enable more verbose logging.
* Tue May 18 2004 lmb@suse.de
- Fix recalc_sigpending useage.
- Activate additional debugging useful for test harness runs.
* Wed May 12 2004 lmb@suse.de
- Update to drbd 0.7-pre7, bugfix release
* Thu Apr 29 2004 kraxel@suse.de
- one more kernel build fix, previous was incomplete :-/
* Wed Apr 28 2004 kraxel@suse.de
- fix kernel build failure.
* Sat Apr 24 2004 lmb@suse.de
- Fix random memory corruption bug.
* Fri Apr 23 2004 lmb@suse.de
- Update to latest CVS to fix SMP issues.
* Tue Apr  6 2004 agruen@suse.de
- Add missing include path (testing with Makefile.suse currently
  does not catch this case).
* Tue Mar 30 2004 lmb@suse.de
- Update to CVS-2004-03-30
- Should fix #37446
- Add new magic for km test builds if kernel-source is present.
* Fri Mar 19 2004 lmb@suse.de
- Update to latest CVS once more.
- Kill any files laying around from patches or CVS artifacts.
* Mon Mar 15 2004 lmb@suse.de
- Update to latest CVS.
* Thu Mar  4 2004 kraxel@suse.de
- add olh's regparm fix.
* Thu Feb 19 2004 lmb@suse.de
- Upgrade to 0.7_pre5 from upstream.
- Include some hacks to test build of the km_ modules.
* Tue Feb 17 2004 lmb@suse.de
- Stale patch included last time.
* Tue Feb 17 2004 lmb@suse.de
- Fix at least the build on ppc64, x86_64 and ia64.
* Mon Feb 16 2004 lmb@suse.de
- Upgrade to drbd 0.7
- Reenable new & wonderful km_drbd package
* Mon Jan 26 2004 ro@suse.de
- comment out km_drbd package
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Sep 10 2003 lmb@suse.de
- Fix some build failures on ppc64.
- Honor CONFIG_DEBUGSYM for UML build.
* Tue Aug 26 2003 lmb@suse.de
- No longer build the ja & pt docs.
* Tue Aug 19 2003 lmb@suse.de
- Do apply the patch.
* Mon Aug 18 2003 lmb@suse.de
- Fix distribution detection.
* Mon Aug 18 2003 lmb@suse.de
- Added build fixes for building under UML.
- Fix for unacked count << 0.
* Thu Jul 31 2003 lmb@suse.de
- Upgrade to 0.6.6.
* Fri Jul 25 2003 schwab@suse.de
- Respect INSTALL_MOD_PATH.
* Wed Jun 11 2003 kukuk@suse.de
- Add all directories to filelist
* Tue Jun  3 2003 jg@suse.de
- Update to 0.6.4, changes:
  - Reworked build system (i.e. better Makefiles)
  - SyncAll works forward insead of backwards. Improves performance on some
    storage controlers.
  - Reworked /etc/init.d/drbd script (i.e. better support of different bash
    releases)
* Wed Mar 26 2003 jg@suse.de
- Update to 0.6.3, changes:
  - Lockup of primary if secondary fails during resync. Fixed. (Stupid!)
  - Probabely SMP only deadlock in the drop-conection code path.
  - Improved connect code. (The old code could trap into a distributed
    deadlock, resulting in an endless connect/disconnect loop.)
  - The 'BitMap too small bug' was actually caused by a patch in
    SuSE's distribution kernel. This patch makes DRBD 'more' compatible
    with SuSE's kernel.
  - Improved code to allocate buffers for the rsynchronisation process.
    The old code allocated physical adjacent pages although the syncer
    does not need them! The old code could fail under high memory pressure.
- Removed BitMap too small patch (is part of 0.6.3)
- added /etc/ha.d/resource.d/datadisk to filelist so it is possible
  to install heartbeat after drbd
- removed unneeded /etc/ha.d/resource.d/drbd-control
* Mon Mar 17 2003 jg@suse.de
- Added "BitMap too small" fix (Bug #25384)
* Wed Feb 12 2003 jg@suse.de
- Updated to 0.6.2
  - SMP fix in drbd_dio_end_sec()
  - /etc/init.d/drbd knows about returncodes of fsck
* Tue Dec 17 2002 jg@suse.de
- Moved drbdsetup from /usr/sbin to /sbin to support /usr on nfs
- Removed accidentialy included CVS directories from tar-file
* Wed Dec 11 2002 jg@suse.de
- Updated to 0.6.1 final
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
- changed neededforbuild <sp> to <opensp>
* Wed Oct  2 2002 jg@suse.de
- Updated to 0.6.1-pre17, changes:
  - Merged syncer speedup code by Lars G. Ellenberg
  - Merged most of Lars' modifications to the ioctl interface
  - Marged the bug-fixes from the lge-branch
  - Implemented the TimoutCounter in the meta-data code.
  - Fixed a bug that could cause lockup of the primary node on
    SMP systems using a SCSI device for DRBD, it always happened
    during resynchronisation. (!)
- Checking /.buildenv now in buildsystem instead of /etc/*-release
* Tue Sep  3 2002 jg@suse.de
- Init script fixes:
  - Removed abortion on non existing block devices (may
    break LVM setups)
  - Sourcing . /etc/rc.status earlier now
  - Allowing execution via rcdrbd link
* Mon Sep  2 2002 jg@suse.de
- Incorporated latest changes from CVS
- Using lge branch now (syncer much faster)
* Wed Aug 21 2002 jg@suse.de
- Fixed manpage generation (should now even build on ppc64)
* Tue Aug 20 2002 jg@suse.de
- Added PreReq tag
* Mon Aug 19 2002 kukuk@suse.de
- fix compilation on UL
* Tue Aug 13 2002 jg@suse.de
- Added documentation stuff again
- Modified init script to comply with LSB
* Mon Aug 12 2002 jg@suse.de
- Updated to latest version from CVS repository
- Removed temporary documentation path from Makefile (does
  not build)
* Tue Mar  5 2002 jg@suse.de
- Fixed broken specfile
* Mon Mar  4 2002 jg@suse.de
- updated to bugfix release 0.6.1pre10
  - Data-corruption bug in SyncAll fixed (was introduced in pre9)
  - Fixed an OOPS in tl_check_sector() (was introduced in pre9)
  - Fixed Linux-2.2.x compability (was broken in pre9)
- removed documentation patch (not needed anymore)
* Wed Feb 20 2002 jg@suse.de
- modified init script to honor inittimeout settings
* Wed Feb 20 2002 jg@suse.de
- added -include /usr/src/linux/include/linux/modversions.h
  to km_drbd Makefile in case CONFIG_MODVERSIONS is set
- modified the init script to comply to LSB and to skip
  the "interactive" part on boot
* Tue Feb 12 2002 jg@suse.de
- added -DMODVERSION and -D__SMP__ to km_drbd Makefile (according
  to kernel configuration)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 29 2002 jg@suse.de
- updated to 0.6.1-pre9
* Thu Dec 20 2001 jg@suse.de
- replaced insserv call in specfile with respective macro
* Wed Dec 19 2001 jg@suse.de
- updated to 0.6.1-pre7 (supports now kernel 2.4)
- removed insserv call after installing
- removed fillup template
- removed some outdated documentation files
* Fri Jul 27 2001 mt@suse.de
- fixed init script to be LSB compliant
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_serv> to <ghostscript-serv>
* Sun Jan 14 2001 mt@suse.de
- added km_drbd subpackage with drbd kernel module source
* Fri Dec  1 2000 mt@suse.de
- added mkdir $RPM_BUILD_ROOT/sbin in spec
* Fri Dec  1 2000 kukuk@suse.de
- move sbin/init.d -> etc/init.d
* Mon Nov 27 2000 mt@suse.de
- fixed link src for rcdrbd in spec file
- changed group to Applications/Clustering
* Thu Nov 23 2000 mt@suse.de
- removed heartbeat from neededforbuild
* Wed Nov 22 2000 mt@suse.de
- changed to LSB installation of run level links
* Fri Nov 10 2000 mt@suse.de
- no module build in spec - drbd module is patched into the kernel
* Wed Nov  8 2000 mt@suse.de
- new package
